from diffusion_webui.diffusion_models.controlnet.controlnet_canny import (
    StableDiffusionControlNetCannyGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_depth import (
    StableDiffusionControlNetDepthGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_hed import (
    StableDiffusionControlNetHEDGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_canny import (
    StableDiffusionControlNetInpaintCannyGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_depth import (
    StableDiffusionControlInpaintNetDepthGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_hed import (
    StableDiffusionControlNetInpaintHedGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_mlsd import (
    StableDiffusionControlNetInpaintMlsdGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_pose import (
    StableDiffusionControlNetInpaintPoseGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_scribble import (
    StableDiffusionControlNetInpaintScribbleGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_inpaint.controlnet_inpaint_seg import (
    StableDiffusionControlNetInpaintSegGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_mlsd import (
    StableDiffusionControlNetMLSDGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_pose import (
    StableDiffusionControlNetPoseGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_scribble import (
    StableDiffusionControlNetScribbleGenerator,
)
from diffusion_webui.diffusion_models.controlnet.controlnet_seg import (
    StableDiffusionControlNetSegGenerator,
)
from diffusion_webui.diffusion_models.stable_diffusion.img2img_app import (
    StableDiffusionImage2ImageGenerator,
)
from diffusion_webui.diffusion_models.stable_diffusion.inpaint_app import (
    StableDiffusionInpaintGenerator,
)
from diffusion_webui.diffusion_models.stable_diffusion.text2img_app import (
    StableDiffusionText2ImageGenerator,
)
